import { ɵɵdefineInjectable, Injectable, Component, ViewEncapsulation, ChangeDetectionStrategy, ElementRef, Optional, Inject, Input, NgModule } from '@angular/core';
import { DOCUMENT } from '@angular/common';

class BootstrapIconsRegistry {
    constructor() {
        this.registry = new Map();
    }
    registerIcons(icons) {
        icons.forEach((icon) => this.registry.set(icon.name, icon.data));
    }
    getIcon(iconName) {
        if (!this.registry.has(iconName)) {
            console.warn(`We could not find the dinosaur Icon with the name ${iconName}, did you add it to the Icon registry?`);
        }
        return this.registry.get(iconName);
    }
}
BootstrapIconsRegistry.ɵprov = ɵɵdefineInjectable({ factory: function BootstrapIconsRegistry_Factory() { return new BootstrapIconsRegistry(); }, token: BootstrapIconsRegistry, providedIn: "root" });
BootstrapIconsRegistry.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];

class BootstrapIconComponent {
    constructor(element, iconsRegistry, document) {
        this.element = element;
        this.iconsRegistry = iconsRegistry;
        this.document = document;
    }
    set name(iconName) {
        if (this.svgIcon) {
            this.element.nativeElement.removeChild(this.svgIcon);
        }
        const svgData = this.iconsRegistry.getIcon(iconName);
        if (svgData) {
            this.svgIcon = this.svgElementFromString(svgData);
            this.element.nativeElement.appendChild(this.svgIcon);
        }
    }
    svgElementFromString(svgContent) {
        const div = this.document.createElement('DIV');
        if (div instanceof HTMLElement) {
            div.innerHTML = svgContent;
            return div.querySelector('svg') || this.document.createElementNS('http://www.w3.org/2000/svg', 'path');
        }
    }
}
BootstrapIconComponent.decorators = [
    { type: Component, args: [{
                selector: 'bootstrap-icon',
                template: `<ng-content></ng-content>`,
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];
BootstrapIconComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: BootstrapIconsRegistry },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [DOCUMENT,] }] }
];
BootstrapIconComponent.propDecorators = {
    name: [{ type: Input }]
};

class BootstrapIconsModule {
    static forRoot() {
        return {
            ngModule: BootstrapIconsModule,
            providers: [
                BootstrapIconsRegistry,
            ],
        };
    }
}
BootstrapIconsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [BootstrapIconComponent],
                imports: [],
                exports: [BootstrapIconComponent]
            },] }
];

/*
 * Public API Surface of the icons lib
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BootstrapIconComponent, BootstrapIconsModule, BootstrapIconsRegistry };
//# sourceMappingURL=triangular-bootstrap-icons.js.map
